﻿using Microsoft.EntityFrameworkCore;
using PizzaShopDAL.Models;

namespace PizzaShopDAL.Data
{
    public static class DataInitializer
    {
        //Specifying IDs is mandatory if seeding db through OnModelCreating method
        public static void Seed(this ModelBuilder modelBuilder)
        {
            var triangle = new Shape { Id = 1, Name = "Triangle" };
            var ham = new Ingredient { Id = 1, Name = "Ham" };

            modelBuilder.Entity<Shape>().HasData(triangle);
            modelBuilder.Entity<Ingredient>().HasData(ham);
            modelBuilder.Entity<Pizza>().HasData
            (
                new Pizza { 
                    Id = 1, 
                    Name = "Hammito", 
                    ShapeId = 1,
                    Height = 10, 
                    Width = 10,
                    Price = 249.99M,
                }
            );
            modelBuilder.Entity<PizzaIngredient>()
                .HasData(new PizzaIngredient { Id = 1, PizzaId = 1, IngredienceId = 1 });

            // for razor pages 

            var cheese = new Ingredient { Id = 2, Name = "Cheese" };
            var pineapple = new Ingredient { Id = 3, Name = "Pineapple" };
            var salami = new Ingredient { Id = 4, Name = "Salami" };
            var meat = new Ingredient { Id = 5, Name = "meat" };

            modelBuilder.Entity<Ingredient>().HasData(cheese);
            modelBuilder.Entity<Ingredient>().HasData(pineapple);
            modelBuilder.Entity<Ingredient>().HasData(salami);
            modelBuilder.Entity<Ingredient>().HasData(meat);
            modelBuilder.Entity<Pizza>().HasData
            (
                new Pizza
                {
                    Id = 2,
                    Name = "Hawai",
                    ShapeId = 1,
                    Height = 10,
                    Width = 10,
                    Price = 249.99M,
                },

                new Pizza
                {
                    Id = 3,
                    Name = "Mixin",
                    ShapeId = 1,
                    Height = 10,
                    Width = 10,
                    Price = 249.99M,
                }
            );

            modelBuilder.Entity<PizzaIngredient>()
                .HasData(new PizzaIngredient { Id = 2, PizzaId = 2, IngredienceId = 1 });
            modelBuilder.Entity<PizzaIngredient>()
                .HasData(new PizzaIngredient { Id = 3, PizzaId = 2, IngredienceId = 2 });
            modelBuilder.Entity<PizzaIngredient>()
                .HasData(new PizzaIngredient { Id = 4, PizzaId = 2, IngredienceId = 3 });
            modelBuilder.Entity<PizzaIngredient>()
                .HasData(new PizzaIngredient { Id = 5, PizzaId = 3, IngredienceId = 2 });
            modelBuilder.Entity<PizzaIngredient>()
                .HasData(new PizzaIngredient { Id = 6, PizzaId = 3, IngredienceId = 3 });
            modelBuilder.Entity<PizzaIngredient>()
                .HasData(new PizzaIngredient { Id = 7, PizzaId = 3, IngredienceId = 4 });
            modelBuilder.Entity<PizzaIngredient>()
                .HasData(new PizzaIngredient { Id = 8, PizzaId = 3, IngredienceId = 5 });
        }
    }
}
