﻿using Microsoft.EntityFrameworkCore;
using System.Linq;
using PizzaShopDAL.Models;

namespace PizzaShopDAL.Data
{
    public class PizzaShopDBContext : DbContext
    {
        private const string DatabaseName = "TestDB-v1";
        private const string ConnectionString = $"Server=(localdb)\\mssqllocaldb;Integrated Security=True;MultipleActiveResultSets=True;Database={DatabaseName};Trusted_Connection=True;";
        
        public DbSet<Ingredient> Ingredient { get; set; }
        public DbSet<Shape> Shape { get; set; }
        public DbSet<Pizza> Pizza { get; set; }
        public DbSet<Box> Box { get; set; }
        public DbSet<PizzaIngredient> PizzaToIngredience { get; set; }

        protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
        {
            optionsBuilder
                .UseSqlServer(ConnectionString)
                .UseLazyLoadingProxies();
        }

        // https://docs.microsoft.com/en-us/ef/core/modeling/
        
        protected override void OnModelCreating(ModelBuilder modelBuilder)
        {
            /* Setup the connection table */
            modelBuilder.Entity<PizzaIngredient>()
                .HasKey(pi => new { pi.PizzaId, pi.IngredienceId });

            /* setup One-To-Many relationship from both sides */
            modelBuilder.Entity<PizzaIngredient>()
                .HasOne(pi => pi.Pizza)
                .WithMany(p => p.PizzaIngredients)
                .HasForeignKey(a => a.PizzaId);

            modelBuilder.Entity<PizzaIngredient>()
                .HasOne(pi => pi.Ingredience)
                .WithMany(p => p.PizzaIngredients)
                .HasForeignKey(a => a.IngredienceId);

            foreach (var relationship in modelBuilder.Model.GetEntityTypes().SelectMany(e => e.GetForeignKeys()))
            {
                relationship.DeleteBehavior = DeleteBehavior.Restrict;
            }

            modelBuilder.Seed();

            base.OnModelCreating(modelBuilder);
        }
        
    }
}
